# AbsBox 
a structured finance cashflow engine wrapper

[![Python version](https://img.shields.io/pypi/pyversions/absbox)](https://img.shields.io/pypi/pyversions/absbox)
[![PyPI version](https://badge.fury.io/py/absbox.svg)](https://badge.fury.io/py/absbox)
[![PyPI download](https://img.shields.io/pypi/dm/absbox)](https://img.shields.io/pypi/dm/absbox)


## installation

    pip install absbox

## Goals
* Provide building blocks to create cashflow models for ABS/MBS
* Adapt to multiple asset class
    * Residential Mortgage / Auto Loans
    * Corp Loans
    * Consumer Credit
* Features
  * Sensitivity Analysis on different scenarios
  * Bond Cashflow Forecast, Pricing

## Documentation
* English -> https://absbox-doc.readthedocs.io
* Chinese -> https://absbox.readthedocs.io
